<?php
/**
 *  YaPiG Installer. 
 *
 * This script does the following tasks:
 *
 *   - check if $BASE_DIR/global-gen.php exists
 *   - if Safe mode => prompt user to add secure directory name
 *   - create index.html files
 *   - create $BASE_DIR/global-gen.php   
 *   - get GD version.
 *
 * @package install
 *
 */

require_once('config.php');
require_once('functions.php');
require_once('admin_func.php');
require_once('install_func.php');

/**
 * Creates a random seed from microtime.
 *
 * @returns float seed.
 */

function make_seed() {
        list($usec, $sec) = explode(' ', microtime());
        return (float) $sec + ((float) $usec * 100000);
}

/**
 * This functions displays a form where user can type the name
 * of the secure dir. 
 * 
 * @global $BASE_DIR
 *
 */

function print_secure_dir_form(){
  global $BASE_DIR;

  $I_SEND=_y('Send');
   echo <<<SDF
<div>
  <form action="install.php" method="post">
  SECURE_DIR: {$BASE_DIR} <input type="text" name="own_secure_dir">
   <input type="submit" value="$I_SEND">
  </form>
</div>
SDF;

}

/// MAIN PROGRAM //////////////////////////////////////

//Interface
include($TEMPLATE_DIR .'face_begin.php');

heading(_y("Yapig installation"));
print_main_menubar();

//If global-gen exists => Stop install. Yapig already installed.
if (file_exists($BASE_DIR . 'global-gen.php')){
  error(_y("YaPiG already installed"));
}


//Random value
srand(make_seed());
$randval = md5(rand() . rand());
$randval2 = md5(rand(). rand());

if (ini_get("safe_mode") != "1") {
  //Now create a random name directory

  $SECURE_DIR="yapig_data." . $randval . "/";
  if (!mkdir($BASE_DIR . $SECURE_DIR ,0777))
    error(_y("Could not create SECURE_DIR. Change your BASE_DIR (view config.php) permissions to 777."));
  
}
elseif (empty($_POST['own_secure_dir'])) {
  msg("Safe mode detected! Cannot continue the installation automatically. Please follow this steps:");
  echo _y("<ol>
	  <li>Create a directory yourself with any random name on \$BASE_DIR (photos/) and set
	  its permissions to 777. This directory, called SECURE_DIR, will
	  be used to save dynamic data.</li>
	  <li>Create an empty file called index.html to both BASE_DIR and
	  SECURE_DIR directories. These are for avoiding server listing.</li>
	  <li>After you have created the directory and set its permissions, 
	  please enter its name here:
          </li>
	  </ol>");

  print_secure_dir_form();
  die;
}
else {
  //Append '/' if required 
  if (!preg_match("/\/\$/",$_POST['own_secure_dir']))
    $_POST['own_secure_dir'].='/';

  if (is_dir($BASE_DIR . $_POST['own_secure_dir'])) 
    $SECURE_DIR = $_POST['own_secure_dir'];	    
  else {
    error(_y("SECURE_DIR does not exist! Please enter the correct directory name:"));
    print_secure_dir_form();
    die;
  }
}


//Create index.html files for avoiding server fancy index.
if (!new_index_file($BASE_DIR . $SECURE_DIR,"../../gallery.php")) {
     warning(_y("Could not create index.html in SECURE_DIR. Read FAQ documentation."));
}
if (!new_index_file($BASE_DIR ,"../gallery.php")) {
  error(_y("Could not create index.html in BASE_DIR. Read FAQ documentation"));
}   

//Try to load GD in case it is not already done.
if (!load_gd(true)) {
    error(_y('Could not load GD library which is required by Yapig or your GD version is too old. Please read doc/install.html documentation for more information.'));
}
else {
    msg(_y('Good! Your server has GD library. You can run Yapig!'));
}


//Get GD version.
if (!($gdv=gdversion())) {
  warning(_y('Could not get GD version. Please read doc/en/install.html documentation for more information.'));
  $gdv=1;
}


if (!($fd=@fopen($BASE_DIR . 'global-gen.php', 'w'))){
  msg(_y("Change Yapig's root directory permissions to allow creating new files."));
  error(_y("Installation aborted. Could not create config file."));
  
}
  fputs($fd,"<?php");
  $contents=<<<HEREDOC

    /****************************************************
     * Generated by YaPiG Installation. Do not modify   *
     ****************************************************/

    /**
     * Secure dir
     *
     * This directory will store all dynamic information.
     *
     *
     */

     \$SECURE_DIR= \$BASE_DIR . "$SECURE_DIR";
    /**
     * gid-directory correspondence file.
     *
     * This file will store the correspondence between gid and dirs in
     * the common correspondence file format.Sample line:
     *    gid \$EQUAL value
     */

    \$GID_DIRS= \$SECURE_DIR . 'gid-dirs.{$randval2}';

    /** phid->filename Correspondence file.
     *
     * This file will have the correspondece beteen photo identificator phid
     * and image filename (just filename without path information).
     *
     * Will be stored in the common correspondence file format. Sample line:
     * phid $EQUAL phid_filename.ext
     *
     */

    \$PHID_FILENAMES='phid.$randval2';

    /**
     * GD_VERSION
     * When yapig is installed it is detected which version is in this system.
     * If it is not automatically detected modify this field. 
     * Set $GD_VERSION=1 for using 1.x GD library
     * Set $GD_VERSION=2 for using 2.x GD library
     * 
     */
     \$GD_VERSION=$gdv;



HEREDOC;
    fputs($fd,$contents);
    fputs($fd, '?>');

    heading(_y("Yapig successfully installed."),3);


       heading(_y("Congratulations Yapig is up and runnig!"),3);

//welcome message
echo "<div class=\"admin\"><h3 style=\"color:black\">";
echo msg(_y('Security Advice: After you have configured all, delete install.php'));

echo "</h3></div>";

//welcome message    
    echo _y('
   <p>Welcome to <a href="http://yapig.sf.net">Yapig.</a></p>
   <p>There are <strong>NO</strong> defined  galleries.<p>
   <p>If this is the first time you run:</p>
   <ol>
   <li>Edit the <i>config.php</i> file.</li>
   <li><a href="admin.php">Login as admin</a> and add a new gallery.</li>
   </ol>
    ');






include($TEMPLATE_DIR . 'face_end.php');

?>
